﻿# The script of the game goes in this file.

# Declare characters used by this game. The color argument colorizes the
# name of the character.

init:
    transform flip:
        xzoom -1.0

    python:
    
        import math

        class Shaker(object):
        
            anchors = {
                'top' : 0.0,
                'center' : 0.5,
                'bottom' : 1.0,
                'left' : 0.0,
                'right' : 1.0,
                }
        
            def __init__(self, start, child, dist):
                if start is None:
                    start = child.get_placement()
                #
                self.start = [ self.anchors.get(i, i) for i in start ]  # central position
                self.dist = dist    # maximum distance, in pixels, from the starting point
                self.child = child
                
            def __call__(self, t, sizes):
                # Float to integer... turns floating point numbers to
                # integers.                
                def fti(x, r):
                    if x is None:
                        x = 0
                    if isinstance(x, float):
                        return int(x * r)
                    else:
                        return x

                xpos, ypos, xanchor, yanchor = [ fti(a, b) for a, b in zip(self.start, sizes) ]

                xpos = xpos - xanchor
                ypos = ypos - yanchor
                
                nx = xpos + (1.0-t) * self.dist * (renpy.random.random()*2-1)
                ny = ypos + (1.0-t) * self.dist * (renpy.random.random()*2-1)

                return (int(nx), int(ny), 0, 0)
        
        def _Shake(start, time, child=None, dist=100.0, **properties):

            move = Shaker(start, child, dist=dist)
        
            return renpy.display.layout.Motion(move,
                          time,
                          child,
                          add_sizes=True,
                          **properties)

        Shake = renpy.curry(_Shake)
    #

#

define hitman = Character("Hitman")
define kid = Character("Kid")
define manager = Character("Manager")
define megan = Character("Megan")
define old = Character("Old Man")
define rich = Character("Rich Girl")
define serial = Character("Mysterious Bunny")
define toilet = Character("Toilet Man")


# The game starts here.

label start:

    play music "gas_station.mp3"

    # Show a background. This uses a placeholder by default, but you can
    # add a file (named either "bg room.png" or "bg room.jpg") to the
    # images directory to show it.

    scene bg store

    # This shows a character sprite. A placeholder is used, but you can
    # replace it by adding a file named "eileen happy.png" to the images
    # directory.

    show megan:
        left
    show manager:
        right
        flip

    # These display lines of dialogue.

    megan "Please, I really need this job. And no one else will hire me."

    manager "I can see why. Your background check was...interesting."

    megan "Listen, I made it halfway through college."

    manager "So a 2.0 GPA, nonetheless? I'm more concerned about the arson charges."

    megan "It was an accident! My family really needs the money."

    manager "I'm just messing with you, I think you are exactly what we need around here. You're hired! The job is pretty simple: just ring the customers up. And remember that they are always right!"

    show manager with move:
        xalign 2.0
    hide manager

    show toilet:
        xalign 2.0
    show toilet with move:
        right

    toilet "Do you have a bathroom?"

    megan "Probably. I don't know, I just started here."

    toilet "Great because I like really, really need to use the bathroom."

    megan "Thanks for sharing."

    toilet "I'm gonna go find it."

    show toilet with move:
        xalign 2.0
    hide toilet

    show rich:
        xalign 2.0
    show rich with move:
        right

    rich "Oh. My. God. Is that you Megan?"

    megan "..."

    rich "How is the gas station life treating you? I would expect nothing less from a felon. Haha!"

    menu:

        "Stay calm":
            jump choice1_calm
        "Angry outburst":
            jump choice2_angry

    label choice1_calm:
        $ angry_flag = False
        megan "Thanks, it's nice to see you too!"
        rich "Ugh! Condescending bitch.\"It was nice to see you too!\" Bye!"
        jump choice1_done

    label choice2_angry:
        $ angry_flag = True
        megan "What you think you're better than me? The only thing better about you is having rich parents. I have to actually take responsibility for my family."
        rich "I don't like your tone, you can't talk to me like that."
        megan "I can talk to you any way I want."
        rich "Ugh! I want to talk to your manager. Or you know what. I'm leaving! You're going to regret this!"
        jump choice1_done

    label choice1_done:

    show rich with move:
        xalign 2.0
    hide rich

    show toilet:
        xalign 2.0
    show toilet with move:
        right

    toilet "Whew. Glad I got that taken care of. I'm really sorry, but I don't have any way to repay you."

    megan "Why would you? The bathroom is free."

    toilet "Okay well, again I'm really sorry."

    show toilet with move:
        xalign 2.0
    hide toilet

    "Weird..."

    scene bg aisle
    with Dissolve(.6)

    show megan:
        left
    show old:
        right

    old "I'd like to get this sushi."

    "The sushi has clearly been there for weeks, if not months, and is covered in green fuzz."

    megan "I don't think-"

    old "Here, this should cover it."

    "The man hands me a 100 dollar bill. He clearly is almost blind. I guess I'll take it."

    old "Mmm, I'm so hungry. *Chomp*"

    old "Oohhh..."

    show old with move:
        yalign 40.0
    hide old

    show serial:
        xalign 2.0
    show serial with move:
        right

    serial "Hello there."

    megan "..."

    serial "I've been watching you, haha."

    megan "Um."

    serial "Haha. I can dispose of this body for you, if you like."

    menu:
        "Call the police.":
            megan "Dialing 911..."
            serial "Oh shit..."
            show serial with move:
                xalign 2.0
            jump choice2_done
        "Go along with it":
            megan "Sure, you do that."
            serial "Okay great I'll just take this body away and eat it-I mean bury it!"
            show megan with move:
                xalign -1.0
            jump choice2_done

    label choice2_done:

    scene bg store
    with Dissolve(.6)

    show megan:
        left

    show manager:
        xalign 2.0
    show manager with move:
        right
        flip

    manager "We have kind of a problem...you're going to need to clean the bathroom."

    megan "A problem?"

    manager "Yeah, a quite large one."

    megan "Okay..."

    scene bg bathroom
    with Dissolve(.6)

    show megan:
        xalign 2.0
    show megan with move:
        right
        flip

    "This is the most amount of poop I've ever seen at a time. It's all over the walls, even the ceiling. How did it even get up there? A mound of poop fills the entire volume of the toilet."

    "I don't even know where to begin..."
    with Shake((0, 0, 0, 0), 2.0, dist=30)

    "What was that noise?"

    scene bg outside
    with Dissolve(.6)

    show megan:
        xalign -1.0
    show megan with move:
        left

    "A car has smashed its way halfway through the gas station wall..."

    show kid:
        xalign 2.0
    show kid with move:
        right

    kid "I brought my car inside, I need a fillup."

    "The kid is clearly artifically deepening his voice."

    megan "How did you even reach the gas? Also, that's not how gas stations work."

    kid "I know stick."

    "He holds up an actual wooden stick."

    show manager:
        xalign -1.0
    show manager with move:
        xalign 0.3

    manager "Oh no. Oh my god, this is terrible! My poor gas station wall!"

    megan "You don't sound too upset really."

    manager "Oh I am very upset, this is very, um, concerning to me. Anyway I need to go do some paperwork or something."

    show manager with move:
        xalign -1.0

    scene bg pump
    with Dissolve(.6)
    show megan at left
    show kid at right

    megan "This is where you get the gas from, dummy."

    kid "Oh. Thank you!"

    show kid with move:
        xalign 2.0

    if angry_flag:

        scene bg store
        with Dissolve(.6)

        show megan:
            xalign -1.0
        show megan with move:
            left

        show hitman:
            xalign 2.0
        show hitman with move:
            right

        hitman "Hello. Are you by chance Megan?"

        megan "I don't see how that's any of your business."

        hitman "Well you seem to match the description. I was sent by your \"friend\" to kill you."

    megan "I'm sick of this place. I'll just find a job someplace else."

    scene bg gas
    with Dissolve(.6)

    megan "Let me just poor a little of this gas everywhere."

    scene bg light
    with Dissolve(.6)

    megan "And a light..."

    scene bg end
    with Dissolve(.6)

    "Once an arsonist, always an arsonist."

    # This ends the game.

    return
